inout

package module
v0.8.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 23, 2019 License: Apache-2.0 Imports: 11 Imported by: 4

README

inout

Build Status

Retrieves contents of the provided source: STDIN, HTTP(S) or FS.

Usage

See cmd/cli/cli.go

Changelog

See CHANGELOG.md

License

Released under the Apache License 2.0.

Documentation

Index

Constants

This section is empty.

Variables

var (
	// Source sets target source of the In-Out.
	Source = func(source string) Option {
		return func(r *Reader) {
			r.source = source
		}
	}

	// Query sets CSS query for the target of In-Out.
	Query = func(query string) Option {
		return func(r *Reader) {
			r.query = query
		}
	}

	// Timeout sets timeout for the operation.
	Timeout = func(timeout time.Duration) Option {
		return func(r *Reader) {
			r.timeout = timeout
		}
	}

	// Verbose enables verbose mode.
	Verbose = func(verbose bool) Option {
		return func(r *Reader) {
			r.verbose = verbose
		}
	}
)

Functions

This section is empty.

Types

type Option added in v0.6.0

type Option func(*Reader)

Option allows to customise instance of In-Out.

type Reader

type Reader struct {
	// contains filtered or unexported fields
}

Reader - Input. This struct provides methods for reading strings and numbers from standard input, file input, URLs, and sockets.

func New

func New(ctx context.Context, source string) (Reader, error)

New initializes an instance of Reader from STDIN, file or web page.

source - the filename or web page name, reads from STDIN if name is empty. Panics on errors.

func NewFromString

func NewFromString(input string) *Reader

NewFromString initializes an input from string.

func NewInOut added in v0.6.0

func NewInOut(ctx context.Context, options ...Option) (Reader, error)

NewInOut initializes an instance of Reader from STDIN, file or web page.

source - the filename or web page name, reads from STDIN if name is empty. Panics on errors.

func (*Reader) Close

func (in *Reader) Close() error

Close closes reader.

func (*Reader) Read added in v0.3.0

func (in *Reader) Read(p []byte) (n int, err error)

Read reads into given bytes (does not close reader).

func (*Reader) ReadLine added in v0.2.0

func (in *Reader) ReadLine() (string, error)

ReadLine reads line from reader (does not close reader).

func (*Reader) ReadLines added in v0.2.0

func (in *Reader) ReadLines() ([]string, error)

ReadLines provides slice of all text lines from input and closes the reader.

func (*Reader) ReadWords added in v0.2.0

func (in *Reader) ReadWords() ([]string, error)

ReadWords provides slice of all words from input split by white space and closes the reader.

Directories

Path Synopsis
cmd
cli command

Jump to