inout

package module
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 7, 2018 License: Apache-2.0 Imports: 7 Imported by: 4

README

inout

Build Status

Input / Output processor.

Usage

See cmd/cli/cli.go

Changelog

See CHANGELOG.md

License

Released under the Apache License 2.0.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Reader

type Reader struct {
	// contains filtered or unexported fields
}

Reader - Input. This struct provides methods for reading strings and numbers from standard input, file input, URLs, and sockets.

func New

func New(name string) (Reader, error)

New initializes an instance of Reader from STDIN, file or web page.

name - the filename or web page name, reads from STDIN if name is empty. Panics on errors.

func NewFromString

func NewFromString(input string) Reader

NewFromString initializes an input from string.

func (*Reader) Close

func (in *Reader) Close()

Close ...

func (*Reader) ReadLine added in v0.2.0

func (in *Reader) ReadLine() (string, error)

ReadLine reads line from reader (does not close reader).

func (*Reader) ReadLines added in v0.2.0

func (in *Reader) ReadLines() ([]string, error)

ReadLines provides slice of text lines from input.

func (*Reader) ReadWords added in v0.2.0

func (in *Reader) ReadWords() ([]string, error)

ReadWords provides slice of words from input split by white space.

Directories

Path Synopsis
cmd
cli command

Jump to