Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Reader ¶
type Reader struct {
// contains filtered or unexported fields
}
Reader - Input. This struct provides methods for reading strings and numbers from standard input, file input, URLs, and sockets.
func New ¶
New initializes an instance of Reader from STDIN, file or web page.
name - the filename or web page name, reads from STDIN if name is empty. Panics on errors.
func NewFromString ¶
NewFromString initializes an input from string.
Click to show internal directories.
Click to hide internal directories.